==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/ContainerResourceRequirementsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.ContainerResourceRequirementsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Resource requirements for each container instance within an online deployment.
 * @property containerResourceLimits Container resource limit info:
 * @property containerResourceRequests Container resource request info:
 */
public data class ContainerResourceRequirementsArgs(
    public val containerResourceLimits: Output<ContainerResourceSettingsArgs>? = null,
    public val containerResourceRequests: Output<ContainerResourceSettingsArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.ContainerResourceRequirementsArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.ContainerResourceRequirementsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.ContainerResourceRequirementsArgs.builder()
            .containerResourceLimits(
                containerResourceLimits?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .containerResourceRequests(
                containerResourceRequests?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ContainerResourceRequirementsArgs].
 */
@PulumiTagMarker
public class ContainerResourceRequirementsArgsBuilder internal constructor() {
    private var containerResourceLimits: Output<ContainerResourceSettingsArgs>? = null

    private var containerResourceRequests: Output<ContainerResourceSettingsArgs>? = null

    /**
     * @param value Container resource limit info:
     */
    @JvmName("gcwjkvngcrqyjbvn")
    public suspend fun containerResourceLimits(`value`: Output<ContainerResourceSettingsArgs>) {
        this.containerResourceLimits = value
    }

    /**
     * @param value Container resource request info:
     */
    @JvmName("qjfwlkckglqviusg")
    public suspend fun containerResourceRequests(`value`: Output<ContainerResourceSettingsArgs>) {
        this.containerResourceRequests = value
    }

    /**
     * @param value Container resource limit info:
     */
    @JvmName("qwrkjatdexhmfotf")
    public suspend fun containerResourceLimits(`value`: ContainerResourceSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerResourceLimits = mapped
    }

    /**
     * @param argument Container resource limit info:
     */
    @JvmName("mvoepvudvlxaqnii")
    public suspend
    fun containerResourceLimits(argument: suspend ContainerResourceSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ContainerResourceSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.containerResourceLimits = mapped
    }

    /**
     * @param value Container resource request info:
     */
    @JvmName("jvscijtxqtvtjmar")
    public suspend fun containerResourceRequests(`value`: ContainerResourceSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerResourceRequests = mapped
    }

    /**
     * @param argument Container resource request info:
     */
    @JvmName("losgybukfrlfaoxl")
    public suspend
    fun containerResourceRequests(argument: suspend ContainerResourceSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ContainerResourceSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.containerResourceRequests = mapped
    }

    internal fun build(): ContainerResourceRequirementsArgs = ContainerResourceRequirementsArgs(
        containerResourceLimits = containerResourceLimits,
        containerResourceRequests = containerResourceRequests,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/ContainerResourceRequirementsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.ContainerResourceRequirementsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Resource requirements for each container instance within an online deployment.
 * @property containerResourceLimits Container resource limit info:
 * @property containerResourceRequests Container resource request info:
 */
public data class ContainerResourceRequirementsArgs(
    public val containerResourceLimits: Output<ContainerResourceSettingsArgs>? = null,
    public val containerResourceRequests: Output<ContainerResourceSettingsArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.ContainerResourceRequirementsArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.ContainerResourceRequirementsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.ContainerResourceRequirementsArgs.builder()
            .containerResourceLimits(
                containerResourceLimits?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .containerResourceRequests(
                containerResourceRequests?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ContainerResourceRequirementsArgs].
 */
@PulumiTagMarker
public class ContainerResourceRequirementsArgsBuilder internal constructor() {
    private var containerResourceLimits: Output<ContainerResourceSettingsArgs>? = null

    private var containerResourceRequests: Output<ContainerResourceSettingsArgs>? = null

    /**
     * @param value Container resource limit info:
     */
    @JvmName("ogsshsrfotcwlcuu")
    public suspend fun containerResourceLimits(`value`: Output<ContainerResourceSettingsArgs>) {
        this.containerResourceLimits = value
    }

    /**
     * @param value Container resource request info:
     */
    @JvmName("yorinropaplgjmlf")
    public suspend fun containerResourceRequests(`value`: Output<ContainerResourceSettingsArgs>) {
        this.containerResourceRequests = value
    }

    /**
     * @param value Container resource limit info:
     */
    @JvmName("yerlsquydyrendpp")
    public suspend fun containerResourceLimits(`value`: ContainerResourceSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerResourceLimits = mapped
    }

    /**
     * @param argument Container resource limit info:
     */
    @JvmName("qpbukrpuygpsabps")
    public suspend
    fun containerResourceLimits(argument: suspend ContainerResourceSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ContainerResourceSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.containerResourceLimits = mapped
    }

    /**
     * @param value Container resource request info:
     */
    @JvmName("pblmwpanucilhxsu")
    public suspend fun containerResourceRequests(`value`: ContainerResourceSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerResourceRequests = mapped
    }

    /**
     * @param argument Container resource request info:
     */
    @JvmName("kbewvnbeiescxwyk")
    public suspend
    fun containerResourceRequests(argument: suspend ContainerResourceSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ContainerResourceSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.containerResourceRequests = mapped
    }

    internal fun build(): ContainerResourceRequirementsArgs = ContainerResourceRequirementsArgs(
        containerResourceLimits = containerResourceLimits,
        containerResourceRequests = containerResourceRequests,
    )
}
